@@ -10,7 +10,7 @@ class PryPrefixLexer(RegexLexer):
     tokens = {
         'root' : [
           # Headings from various pry commands
-          (r'^[A-Z][a-z ]+(:\n| .*\n)', bygroups(Keyword, Text)),
+          (r'^([A-Z][a-z ]+)(:\n|: .*\n)', bygroups(Keyword, Text)),
           # line-numbered code listings
           (r'^( *(?:=> *)?)(\d+)(: )(.*\n)', bygroups(Text, Number, Text, Other)),
           # Match the default prompt: [1] pry(main)>
